module.exports = {
  docs: [
    {
      type: 'category',
      label: 'Overview',
      items: [
        'installation',
        'defining-entities',
        'relationships',
        'entity-manager',
        'unit-of-work',
      ],
    },
    {
      type: 'category',
      label: 'Fundamentals',
      link: {
        type: 'generated-index',
        title: 'Fundamentals',
        slug: '/fundamentals',
        keywords: ['fundamentals'],
      },
      items: [
        'identity-map',
        'entity-references',
        'collections',
        'repositories',
        'transactions',
        'inheritance-mapping',
        'cascading',
        'filters',
        'deployment',
        'query-builder',
        'caching',
        'logging',
      ],
    },
    {
      type: 'category',
      label: 'Advanced Features',
      link: {
        type: 'generated-index',
        title: 'Advanced Features',
        slug: '/advanced',
        keywords: ['advanced'],
      },
      items: [
        'nested-populate',
        'query-conditions',
        'propagation',
        'loading-strategies',
        'serializing',
        'entity-helper',
        'events',
        'composite-keys',
        'custom-types',
        'embeddables',
        'entity-schema',
        'json-properties',
        'metadata-providers',
        'metadata-cache',
        'schema-generator',
        'entity-generator',
        'naming-strategy',
        'property-validation',
        'migrations',
        'seeding',
        'read-connections',
      ],
    },
    {
      type: 'category',
      label: 'Reference',
      link: {
        type: 'generated-index',
        title: 'Reference',
        slug: '/reference',
        keywords: ['api reference'],
      },
      items: [
        { type: 'link', label: 'EntityManager API', href: '/api/next/core/class/EntityManager' },
        { type: 'link', label: 'EntityRepository API', href: '/api/next/core/class/EntityRepository' },
        { type: 'link', label: 'QueryBuilder API', href: '/api/next/knex/class/QueryBuilder' },
        'decorators',
        'configuration',
      ],
    },
    {
      type: 'category',
      label: 'Usage with Different Drivers',
      link: {
        type: 'generated-index',
        title: 'Usage with Different Drivers',
        slug: '/drivers',
        keywords: ['usage with drivers'],
      },
      items: [
        'usage-with-sql',
        'usage-with-mongo',
      ],
    },
    {
      type: 'category',
      label: 'Recipes',
      link: {
        type: 'generated-index',
        title: 'Recipes',
        slug: '/recipes',
        keywords: ['recipes'],
      },
      items: [
        'quick-start',
        'usage-with-nestjs',
        'usage-with-js',
        'usage-with-babel',
        'usage-with-adminjs',
        'entity-constructors',
        'multiple-schemas',
        'using-bigint-pks',
        'async-local-storage',
        'custom-driver',
      ],
    },
    {
      type: 'category',
      label: 'Example Integrations',
      link: {
        type: 'generated-index',
        title: 'Example Integrations',
        slug: '/examples',
        keywords: ['examples integrations'],
      },
      items: [
        { type: 'link', label: 'Express + MongoDB + TypeScript', href: 'https://github.com/mikro-orm/express-ts-example-app' },
        { type: 'link', label: 'NestJS + MySQL + TypeScript', href: 'https://github.com/mikro-orm/nestjs-example-app' },
        { type: 'link', label: 'RealWorld example app (Nest + MySQL)', href: 'https://github.com/mikro-orm/nestjs-realworld-example-app' },
        { type: 'link', label: 'Express + MongoDB + JavaScript', href: 'https://github.com/mikro-orm/express-js-example-app' },
        { type: 'link', label: 'Koa + SQLite + TypeScript', href: 'https://github.com/mikro-orm/koa-ts-example-app' },
        { type: 'link', label: 'Inversify + PostgreSQL', href: 'https://github.com/PodaruDragos/inversify-example-app' },
        { type: 'link', label: 'NextJS + MySQL', href: 'https://github.com/jonahallibone/mikro-orm-nextjs' },
        { type: 'link', label: 'GraphQL + PostgreSQL + TypeScript', href: 'https://github.com/driescroons/mikro-orm-graphql-example' },
      ],
    },
    {
      type: 'category',
      label: 'Upgrading',
      link: {
        type: 'generated-index',
        title: 'Upgrading',
        slug: '/upgrading',
        keywords: ['upgrading'],
      },
      items: [
        'upgrading-v4-to-v5',
        'upgrading-v3-to-v4',
        'upgrading-v2-to-v3',
      ],
    },
  ],
};
